summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/kstarsdatetime.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/kstarsdatetime.h')
-rw-r--r--kstars/kstars/kstarsdatetime.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kstars/kstars/kstarsdatetime.h b/kstars/kstars/kstarsdatetime.h
index 37e565aa..a45e2495 100644
--- a/kstars/kstars/kstarsdatetime.h
+++ b/kstars/kstars/kstarsdatetime.h
@@ -88,9 +88,9 @@ public:
*@short Constructor
*Create a KStarsDateTimne based on the specified Date and Time.
*@p _d The ExtDate to assign
*@p _t The QTime to assign
*/
- KStarsDateTime( const ExtDate &_d, const QTime &_t );
+ KStarsDateTime( const ExtDate &_d, const TQTime &_t );
/**
*Assign the (long double) Julian Day value, which includes the time of day
@@ -106,10 +106,10 @@ public:
void setDate( const ExtDate &d );
/**
*Assign the Time according to a QTime object.
*@p t the QTime to assign
*/
- void setTime( const QTime &t );
+ void setTime( const TQTime &t );
/**
*Modify the Date/Time by adding a number of seconds.
@@ -167,7 +167,7 @@ public:
*Convert a given Greenwich Sidereal Time to Universal Time (=Greenwich Mean Time).
*@p GST the Greenwich Sidereal Time to convert to Universal Time.
*/
- QTime GSTtoUT( dms GST ) const;
+ TQTime GSTtoUT( dms GST ) const;
/**
@@ -88,9 +88,9 @@ public:
*Create a KStarsDateTimne based on the specified Date and Time.
*@p _d The ExtDate to assign
- *@p _t The QTime to assign
+ *@p _t The TQTime to assign
*/
@@ -106,10 +106,10 @@ public:
void setDate( const ExtDate &d );
/**
- *Assign the Time according to a QTime object.
- *@p t the QTime to assign
+ *Assign the Time according to a TQTime object.
+ *@p t the TQTime to assign
*/